powered by
This function calculates the loxodrome angle (i.e rhumb line or constant compass heading) between two points on a sphere.
NCEP.loxodrome(lat1,lat2,lon1,lon2)
A numeric value indicating the loxodrome angle between the two input points in degrees from north.
A numeric value giving the starting latitude in decimal degrees.
A numeric value giving the ending latitude in decimal degrees.
A numeric value giving the starting longitude in decimal degrees.
A numeric value giving the ending longitude in decimal degrees.
Michael U. Kemp mukemp+RNCEP@gmail.com
This function calculates the loxodrome angle (i.e. rhumb line or constant compass heading) between two points on a sphere. Output is given in degrees from north.
https://en.wikipedia.org/wiki/Rhumb_line
library(RNCEP) ## Using NCEP.loxodrome ## NCEP.loxodrome(lat1=45,lat2=40,lon1=4,lon2=5)
Run the code above in your browser using DataLab